@@ -171,6 +171,7 @@ options:
     choices:
       - no
       - on-failure
+      - oneshot
       - always
       - unless-stopped
   restart_retries:
@@ -304,6 +305,7 @@ def generate_module():
         restart_policy=dict(required=False, type='str', choices=[
                             'no',
                             'on-failure',
+                            'oneshot',
                             'always',
                             'unless-stopped']),
         restart_retries=dict(required=False, type='int'),
