@@ -7,7 +7,22 @@ set -o errexit
 export PYTHONUNBUFFERED=1
 
 
-check_failure() {
+check_podman_failures() {
+    failed_containers=$(sudo podman ps -a --format "{{.Names}}" \
+        --filter status=created \
+        --filter status=paused \
+        --filter status=exited \
+        --filter status=unknown)
+}
+
+
+check_podman_unhealthies() {
+    unhealthy_containers=$(sudo podman ps -a --format "{{.Names}}" \
+        --filter health=unhealthy)
+}
+
+
+check_docker_failures() {
     # All docker container's status are created, restarting, running, removing,
     # paused, exited and dead. Containers without running status are treated as
     # failure. removing is added in docker 1.13, just ignore it now.
@@ -19,20 +34,31 @@ check_failure() {
         --filter status=paused \
         --filter status=exited \
         --filter status=dead)
+}
 
+
+check_docker_unhealthies() {
     unhealthy_containers=$(sudo docker ps -a --format "{{.Names}}" \
         --filter health=unhealthy)
+}
+
+
+check_failure() {
+    if [ "$CONTAINER_ENGINE" = "docker" ]; then
+        check_docker_failures
+        check_docker_unhealthies
+    elif [ "$CONTAINER_ENGINE" = "podman" ]; then
+        check_podman_failures
+        check_podman_unhealthies
+    else
+        echo "Invalid container engine: ${CONTAINER_ENGINE}"
+        exit 1
+    fi
 
     if [[ -n "$unhealthy_containers" ]]; then
         exit 1;
     fi
 
-    # NOTE(mgoddard): monasca-thresh is a one-shot container that exits but
-    # remains in place, leaving it with a status of exited. This is harmless.
-    if [[ "$failed_containers" = "monasca_thresh" ]]; then
-        exit 0
-    fi
-
     if [[ -n "$failed_containers" ]]; then
         exit 1;
     fi
